@@ -5,7 +5,7 @@ set -o pipefail
 set -o nounset
 
 host_arch="${DEB_HOST_ARCH:-$(dpkg --print-architecture)}"
-jdk_path=$(echo /usr/lib/jvm/java-24-openjdk-amd64 | sed "s/-[^-]*$/-$host_arch/")
+jdk_path=$(echo /usr/lib/jvm/java-25-openjdk-amd64 | sed "s/-[^-]*$/-$host_arch/")
 
 
 echo Check that PC/SC support can be loaded
@@ -27,7 +27,7 @@ EOF
 ${jdk_path}/bin/java -Djava.security.debug=all \
     -cp . ${AUTOPKGTEST_TMP}/Test.java > ${AUTOPKGTEST_TMP}/dependencies-pcsc.log 2>&1
 
-if grep "pcsc: Using PC/SC library" ${AUTOPKGTEST_TMP}/dependencies-pcsc.log; then
+if grep "Using PC/SC library" ${AUTOPKGTEST_TMP}/dependencies-pcsc.log; then
     echo "Test passed."
 else
     cat ${AUTOPKGTEST_TMP}/dependencies-pcsc.log
